cordova.define("uc-cordova-plugin-mxo.MedalliaMXO", function(require, exports, module) {
'use strict';

var cordova$1 = require('cordova');

function _interopNamespaceDefault(e) {
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n.default = e;
    return Object.freeze(n);
}

var cordova__namespace = /*#__PURE__*/_interopNamespaceDefault(cordova$1);

const cordovaExec = async (jsFnName, args) => {
    return await new Promise((resolve, reject) => {
        cordova__namespace.exec((msg) => {
            resolve(msg);
        }, (error) => {
            reject(error);
        }, 
        // this is defined in the plugin.xml, the name attribute on the js-module node
        'MedalliaMXO', jsFnName, args);
    });
};

const setConfiguration = async (config) => {
    return await cordovaExec('setConfiguration', [config]);
};
const getConfiguration = async () => {
    return await cordovaExec('getConfiguration');
};

const clearTid = async () => {
    return await cordovaExec('clearTid');
};
const getTid = async () => {
    return await cordovaExec('getTid');
};

const sendInteraction = async (request) => {
    return await cordovaExec('sendInteraction', [request]);
};
const sendProperties = async (request) => {
    return await cordovaExec('sendProperties', [request]);
};
const sendInteractionResponseCode = async (request) => {
    return await cordovaExec('sendInteractionResponseCode', [request]);
};
const processResponse = async (response) => {
    return await cordovaExec('processResponse', [response]);
};
const sendInteractionForOutboundLink = async (url) => {
    return await cordovaExec('sendInteractionForOutboundLink', [url]);
};

const mxoSdkVersion = '1.0.2';
const setCordovaVersion = () => {
    var _a;
    try {
        const cordovaVersion = (_a = cordova.version) !== null && _a !== void 0 ? _a : 'unknown';
        void cordovaExec('setCordovaVersion', [{ mxoSdkVersion, cordovaVersion }]);
    }
    catch (ignored) {
    }
};
setCordovaVersion();
const getVersion = async () => {
    return await cordovaExec('getVersion')
        .then((version) => {
        if ((version instanceof String || typeof version === 'string') && version !== '') {
            return String(version) + '-' + mxoSdkVersion;
        }
        else {
            return mxoSdkVersion;
        }
    });
};

class MXOIdentityTransferConfiguration {
    constructor(disableIdentityTransfer, includeList, excludeList) {
        this.disableIdentityTransfer = disableIdentityTransfer;
        this.includeList = includeList;
        this.excludeList = excludeList;
    }
}

class MXOIdentityTransferUriMatcher {
    constructor(value) {
        this.value = value;
    }
}

const setIdentityTransferConfiguration = async (config) => {
    return await cordovaExec('setIdentityTransferConfiguration', [config]);
};
const getIdentityTransferConfiguration = async () => {
    const config = await cordovaExec('getIdentityTransferConfiguration');
    const disableIdentityTransfer = config.disableIdentityTransfer;
    const toMatcher = (item) => {
        let matcher = item;
        try {
            matcher = new URL(item);
        }
        catch (ignored) { }
        return new MXOIdentityTransferUriMatcher(matcher);
    };
    const includeList = config.includeList.map(toMatcher);
    const excludeList = config.excludeList.map(toMatcher);
    return new MXOIdentityTransferConfiguration(disableIdentityTransfer, includeList, excludeList);
};
const generateIdentityTransferUrl = async (url) => {
    const newUrl = await cordovaExec('generateIdentityTransferUrl', [url]);
    return new URL(newUrl);
};
const processDeepLink = async (url) => {
    return await cordovaExec('processDeepLink', [url]);
};

const setAutomaticInteractionTrackingConfiguration = async (config) => {
    return await cordovaExec('setAutomaticInteractionTrackingConfiguration', [config]);
};
const getAutomaticInteractionTrackingConfiguration = async () => {
    return await cordovaExec('getAutomaticInteractionTrackingConfiguration');
};

const setOptOutConfiguration = async (config) => {
    return await cordovaExec('setOptOutConfiguration', [config]);
};
const getOptOutConfiguration = async () => {
    return await cordovaExec('getOptOutConfiguration');
};

const processLocation = async (location) => {
    return await cordovaExec('processLocation', [location]);
};

const setLoggingConfiguration = async (config) => {
    return await cordovaExec('setLoggingConfiguration', [config]);
};
const getLoggingConfiguration = async () => {
    return await cordovaExec('getLoggingConfiguration');
};

const MedalliaMXO = {
    getConfiguration,
    setConfiguration,
    getOptOutConfiguration,
    setOptOutConfiguration,
    setLoggingConfiguration,
    getLoggingConfiguration,
    getAutomaticInteractionTrackingConfiguration,
    setAutomaticInteractionTrackingConfiguration,
    getIdentityTransferConfiguration,
    setIdentityTransferConfiguration,
    generateIdentityTransferUrl,
    processDeepLink,
    getVersion,
    getTid,
    clearTid,
    processLocation,
    sendInteraction,
    sendProperties,
    sendInteractionResponseCode,
    sendInteractionForOutboundLink,
    processResponse
};

module.exports = MedalliaMXO;

});
