cordova.define("uc-cordova-plugin-mxo.One", function(require, exports, module) {

function init(successCallback, errorCallback) {
    //UC code change
    let configObject = { }
    return window.MedalliaMXO.setConfiguration(configObject).then(function (result) {
        successCallback(result);
    }).catch(function (error) {
        // console.log("[MXO]", error, JSON.stringify(error,null,4));
        let oneError =  error.message + ":" + error.cause;
        errorCallback(oneError);
    });
    //end UC code change

}

function optOut(status, keychain) {
    return window.MedalliaMXO.setOptOutConfiguration({optOut: status});
}

function sendInteraction(interactionPath, properties = {}, successCallback, errorCallback) {
    let interaction = {
        "interaction": interactionPath,
        "properties": properties
    };
    let response = '';
    return window.MedalliaMXO.sendInteraction(interaction).then(function (result) {
        response = result;
        let oneResult = {
            optimizations: result.optimizationPoints.map(optimisationPoint => {
                var mimeType = "";
                if(optimisationPoint && optimisationPoint["actions"]){
                    optimisationPoint["actions"].forEach(act => {
                        if(act["asset"]) {
                                let asset = act["asset"];
                        asset["content"] = asset["markup"];
                        act = asset;
                        mimeType = asset[["mimeType"]];
                        }
                        
                    });
                } else {
                    optimisationPoint["actions"] = [];
                }
                
                let otp = {
                    data  : btoa(JSON.stringify(optimisationPoint)),
                    path: optimisationPoint["path"],
                    dataMimeType: mimeType ? mimeType : " ",
                    directives:optimisationPoint["directives"] ? optimisationPoint["directives"] :""
                }
                return  otp ;
                
            }),
            captures: result.captureAttributePoints,
            trackers: result.captureActivityPoints,
            tid: result.tid,
            statusCode: result.isSuccess ? 200 : 400
        };
        successCallback(oneResult);
    }).catch(function (error) {
        // console.log("[MXO]", error, JSON.stringify(error,null,4));
        let oneError =  error.message + ":" + error.cause + "response: " +response.toString() ;
        errorCallback(oneError);
    });
}
function sendProperties(interactionPath, properties = {}, successCallback, errorCallback) {
    let interaction = {
        "interaction": interactionPath,
        "properties": properties
    };
    return window.MedalliaMXO.sendProperties(interaction).then(function (result) {
        let oneResult = "OK"
        successCallback(oneResult);
    }).catch(function (error) {
        let oneError = error.message;
        errorCallback(oneError);
    });
}

function sendResponseCode(responseCode, interactionPath, success, error) {
    let mxoResponseCode = {
        interaction: interactionPath,
        responseCode: responseCode
    };
    return window.MedalliaMXO.sendInteractionResponseCode(mxoResponseCode).then(success).catch(error);
}

function sendBaseTouchpointProperties(properties, successCallback, errorCallback) {
    let interaction = {
        "interaction": "/",
        "properties": properties
    };
    return window.MedalliaMXO.sendProperties(interaction).then(function (result) {
        let oneResult = "OK"
        successCallback(oneResult);
    }).catch(function (error) {
        let oneError = error.message;
        errorCallback(oneError);
    });
}

function getTid(success) {
    return window.MedalliaMXO.getTid().then(success).catch();
}

function setLogLevel(logLevel) {
    return window.MedalliaMXO.setLoggingConfiguration({levels: logLevel});
}

function clearUserProfile(success, error) {
    return window.MedalliaMXO.clearTid().then(success).catch(error);
}

function sendInteractionForOutboundLink(url, success, error) {
    return window.MedalliaMXO.sendInteractionForOutboundLink(url).then(success).catch(error);
}

function getURLWithOneTid(url, successHandler, errorHandler) {
    return window.MedalliaMXO.generateIdentityTransferUrl(url).then(function (result) {
        let oneResult = result.href;
        return successHandler(oneResult);
    }).catch(errorHandler);
}

function disableIdentityTransfer(status, success, error) {
    let mxoConfig = {
        disableIdentityTransfer: status
    }
    return window.MedalliaMXO.setIdentityTransferConfiguration(mxoConfig).then(success).catch(error);
}



function disableAutomaticOutboundLinkTracking(status, success, error) {
    return window.MedalliaMXO.disableAutomaticOutboundLinkTracking(status).then(success).catch(error);
}

function handleURL(incomingURL, success, error) {
    return window.MedalliaMXO.handleURL(incomingURL).then(success).catch(error);
}

function whitelistIdentityTransferLinks(list, success, error) {
    let mxoConfig = {
        disableIdentityTransfer: false,
        includeList: new Set(list)
    };
    return window.MedalliaMXO.setIdentityTransferConfiguration(mxoConfig).then(success).catch(error);
}

function blacklistIdentityTransferLinks(list, success, error) {
    let mxoConfig = {
        disableIdentityTransfer: false,
        excludeList: list
    };
    return window.MedalliaMXO.setIdentityTransferConfiguration(mxoConfig).then(success).catch(error);
}

let LogLevel = {
    "NONE": ["NONE"],
    "ALL": ["VERBOSE","DEBUG","ERROR","WARN","INFO"]
};


window.One = {
    init: init, // tested
    optOut: optOut, // tested
    sendInteraction: sendInteraction, // tested
    sendProperties: sendProperties, // tested
    sendResponseCode: sendResponseCode, // tested
    sendBaseTouchpointProperties: sendBaseTouchpointProperties, // tested
    getTid: getTid, // tested
    // setLogLevel: setLogLevel, // Not implemented
    clearUserProfile: clearUserProfile, // tested
    sendInteractionForOutboundLink: sendInteractionForOutboundLink, // tested
    getURLWithOneTid: getURLWithOneTid, // tested
    disableIdentityTransfer: disableIdentityTransfer,
    // disableAutomaticOutboundLinkTracking: disableAutomaticOutboundLinkTracking, // Not implemented
    // handleURL: handleURL, // Not Implimented
    whitelistIdentityTransferLinks: whitelistIdentityTransferLinks,
    blacklistIdentityTransferLinks: blacklistIdentityTransferLinks,
    LogLevel: LogLevel // constants
}

});
